@@ -53,18 +53,18 @@ from .literals import (
 )
 from .type_defs import (
     BuildBatchFilterTypeDef,
-    DescribeCodeCoveragesOutputResponseTypeDef,
-    DescribeTestCasesOutputResponseTypeDef,
-    ListBuildBatchesForProjectOutputResponseTypeDef,
-    ListBuildBatchesOutputResponseTypeDef,
-    ListBuildsForProjectOutputResponseTypeDef,
-    ListBuildsOutputResponseTypeDef,
-    ListProjectsOutputResponseTypeDef,
-    ListReportGroupsOutputResponseTypeDef,
-    ListReportsForReportGroupOutputResponseTypeDef,
-    ListReportsOutputResponseTypeDef,
-    ListSharedProjectsOutputResponseTypeDef,
-    ListSharedReportGroupsOutputResponseTypeDef,
+    DescribeCodeCoveragesOutputTypeDef,
+    DescribeTestCasesOutputTypeDef,
+    ListBuildBatchesForProjectOutputTypeDef,
+    ListBuildBatchesOutputTypeDef,
+    ListBuildsForProjectOutputTypeDef,
+    ListBuildsOutputTypeDef,
+    ListProjectsOutputTypeDef,
+    ListReportGroupsOutputTypeDef,
+    ListReportsForReportGroupOutputTypeDef,
+    ListReportsOutputTypeDef,
+    ListSharedProjectsOutputTypeDef,
+    ListSharedReportGroupsOutputTypeDef,
     PaginatorConfigTypeDef,
     ReportFilterTypeDef,
     TestCaseFilterTypeDef,
@@ -88,7 +88,7 @@ __all__ = (
 
 class DescribeCodeCoveragesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describecodecoveragespaginator)
     """
 
@@ -101,16 +101,16 @@ class DescribeCodeCoveragesPaginator(Boto3Paginator):
         minLineCoveragePercentage: float = None,
         maxLineCoveragePercentage: float = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeCodeCoveragesOutputResponseTypeDef]:
+    ) -> Iterator[DescribeCodeCoveragesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describecodecoveragespaginator)
         """
 
 
 class DescribeTestCasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describetestcasespaginator)
     """
 
@@ -120,16 +120,16 @@ class DescribeTestCasesPaginator(Boto3Paginator):
         reportArn: str,
         filter: "TestCaseFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeTestCasesOutputResponseTypeDef]:
+    ) -> Iterator[DescribeTestCasesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describetestcasespaginator)
         """
 
 
 class ListBuildBatchesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchespaginator)
     """
 
@@ -139,16 +139,16 @@ class ListBuildBatchesPaginator(Boto3Paginator):
         filter: "BuildBatchFilterTypeDef" = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildBatchesOutputResponseTypeDef]:
+    ) -> Iterator[ListBuildBatchesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchespaginator)
         """
 
 
 class ListBuildBatchesForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchesforprojectpaginator)
     """
 
@@ -159,16 +159,16 @@ class ListBuildBatchesForProjectPaginator(Boto3Paginator):
         filter: "BuildBatchFilterTypeDef" = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildBatchesForProjectOutputResponseTypeDef]:
+    ) -> Iterator[ListBuildBatchesForProjectOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchesforprojectpaginator)
         """
 
 
 class ListBuildsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildspaginator)
     """
 
@@ -177,16 +177,16 @@ class ListBuildsPaginator(Boto3Paginator):
         *,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildsOutputResponseTypeDef]:
+    ) -> Iterator[ListBuildsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildspaginator)
         """
 
 
 class ListBuildsForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildsforprojectpaginator)
     """
 
@@ -196,16 +196,16 @@ class ListBuildsForProjectPaginator(Boto3Paginator):
         projectName: str,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildsForProjectOutputResponseTypeDef]:
+    ) -> Iterator[ListBuildsForProjectOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildsforprojectpaginator)
         """
 
 
 class ListProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listprojectspaginator)
     """
 
@@ -215,16 +215,16 @@ class ListProjectsPaginator(Boto3Paginator):
         sortBy: ProjectSortByTypeType = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProjectsOutputResponseTypeDef]:
+    ) -> Iterator[ListProjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listprojectspaginator)
         """
 
 
 class ListReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportgroupspaginator)
     """
 
@@ -234,16 +234,16 @@ class ListReportGroupsPaginator(Boto3Paginator):
         sortOrder: SortOrderTypeType = None,
         sortBy: ReportGroupSortByTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListReportGroupsOutputResponseTypeDef]:
+    ) -> Iterator[ListReportGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportgroupspaginator)
         """
 
 
 class ListReportsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportspaginator)
     """
 
@@ -253,16 +253,16 @@ class ListReportsPaginator(Boto3Paginator):
         sortOrder: SortOrderTypeType = None,
         filter: "ReportFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListReportsOutputResponseTypeDef]:
+    ) -> Iterator[ListReportsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportspaginator)
         """
 
 
 class ListReportsForReportGroupPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportsforreportgrouppaginator)
     """
 
@@ -273,16 +273,16 @@ class ListReportsForReportGroupPaginator(Boto3Paginator):
         sortOrder: SortOrderTypeType = None,
         filter: "ReportFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListReportsForReportGroupOutputResponseTypeDef]:
+    ) -> Iterator[ListReportsForReportGroupOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportsforreportgrouppaginator)
         """
 
 
 class ListSharedProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedprojectspaginator)
     """
 
@@ -292,16 +292,16 @@ class ListSharedProjectsPaginator(Boto3Paginator):
         sortBy: SharedResourceSortByTypeType = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSharedProjectsOutputResponseTypeDef]:
+    ) -> Iterator[ListSharedProjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedprojectspaginator)
         """
 
 
 class ListSharedReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedreportgroupspaginator)
     """
 
@@ -311,8 +311,8 @@ class ListSharedReportGroupsPaginator(Boto3Paginator):
         sortOrder: SortOrderTypeType = None,
         sortBy: SharedResourceSortByTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSharedReportGroupsOutputResponseTypeDef]:
+    ) -> Iterator[ListSharedReportGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedreportgroupspaginator)
         """
